Pure-Rust COPC reader.
Parses LAS/COPC metadata and exposes chunked-LAZ point iteration over COPC hierarchy entries.
Structs
- Column
Selection - Requested LAS/COPC dimensions for column-oriented reads.
- Column
Spec - Declares the LAS/COPC dimension and scalar type for a column.
- Copc
File - A parsed COPC file.
- Copc
Reader - COPC point reader owning the underlying stream.
- LasColumn
Batch - A column-oriented batch of LAS/COPC point values.
- LasHeader
- Minimal LAS header fields needed by COPC callers.
- Point
Iter - Iterator over selected COPC point chunks.
- Point
Query - Point query used by
CopcReader::points_for_query.
Enums
- Bounds
Selection - Limits points by XYZ bounds.
- Column
Data - Owned column values.
- Column
View - Borrowed column values.
- LasDimension
- LAS/COPC point dimensions that can be represented as columns.
- LodSelection
- Limits the octree levels included in a point query.
- Scalar
Type - Primitive scalar types supported by LAS/COPC column data.